From 43b75c4473c24a3713400111b5b706b148af5b0b Mon Sep 17 00:00:00 2001
From: Steve French <smfrench@gmail.com>
Date: Wed, 13 Apr 2016 23:18:45 -0500
Subject: [PATCH] CIFS: Fix formatting issues on previous patches spotted by
 checkpatch

Trivial change.

One block comment from previous patch had wrong format, and existing
xattr code had incorrect indentation in one function - the checkpatch
on the recent patches from Andreas spotted it.  Make checkpatch
happy.

Signed-off-by: Steve French <steve.french@primarydata.com>
CC: Andreas Gruenbacher <agruenba@redhat.com>
---
 fs/cifs/xattr.c | 52 +++++++++++++++++++++++++++-------------------------
 1 file changed, 27 insertions(+), 25 deletions(-)

diff --git a/fs/cifs/xattr.c b/fs/cifs/xattr.c
index af2b5be..b6e468c 100644
--- a/fs/cifs/xattr.c
+++ b/fs/cifs/xattr.c
@@ -221,9 +221,11 @@ int cifs_setxattr(struct dentry *direntry, const char *ea_name,
 		} else {
 			cifs_dbg(FYI, "illegal xattr request %s (only user namespace supported)\n",
 				 ea_name);
-		  /* BB what if no namespace prefix? */
-		  /* Should we just pass them to server, except for
-		  system and perhaps security prefixes? */
+			/*
+			 * BB what if no namespace prefix?
+			 * Should we just pass them to server, except for
+			 * system and perhaps security prefixes?
+			 */
 		}
 	}
 
@@ -317,30 +319,30 @@ ssize_t cifs_getxattr(struct dentry *direntry, const char *ea_name,
 #endif /* CONFIG_CIFS_POSIX */
 	} else if (strcmp(ea_name, CIFS_XATTR_CIFS_ACL) == 0) {
 #ifdef CONFIG_CIFS_ACL
-			u32 acllen;
-			struct cifs_ntsd *pacl;
-
-			if (pTcon->ses->server->ops->get_acl == NULL)
-				goto get_ea_exit; /* rc already EOPNOTSUPP */
-
-			pacl = pTcon->ses->server->ops->get_acl(cifs_sb,
-					d_inode(direntry), full_path, &acllen);
-			if (IS_ERR(pacl)) {
-				rc = PTR_ERR(pacl);
-				cifs_dbg(VFS, "%s: error %zd getting sec desc\n",
-					 __func__, rc);
-			} else {
-				if (ea_value) {
-					if (acllen > buf_size)
-						acllen = -ERANGE;
-					else
-						memcpy(ea_value, pacl, acllen);
-				}
-				rc = acllen;
-				kfree(pacl);
+		u32 acllen;
+		struct cifs_ntsd *pacl;
+
+		if (pTcon->ses->server->ops->get_acl == NULL)
+			goto get_ea_exit; /* rc already EOPNOTSUPP */
+
+		pacl = pTcon->ses->server->ops->get_acl(cifs_sb,
+				d_inode(direntry), full_path, &acllen);
+		if (IS_ERR(pacl)) {
+			rc = PTR_ERR(pacl);
+			cifs_dbg(VFS, "%s: error %zd getting sec desc\n",
+				 __func__, rc);
+		} else {
+			if (ea_value) {
+				if (acllen > buf_size)
+					acllen = -ERANGE;
+				else
+					memcpy(ea_value, pacl, acllen);
 			}
+			rc = acllen;
+			kfree(pacl);
+		}
 #else
-			cifs_dbg(FYI, "Query CIFS ACL not supported yet\n");
+		cifs_dbg(FYI, "Query CIFS ACL not supported yet\n");
 #endif /* CONFIG_CIFS_ACL */
 	} else if (strncmp(ea_name,
 		  XATTR_TRUSTED_PREFIX, XATTR_TRUSTED_PREFIX_LEN) == 0) {
-- 
1.9.1

